/*
 * Copyright 2021 Neural Layer
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.roboquant.common

import org.junit.Test
import kotlin.test.assertEquals

internal class TimelineTest {


    @Test
    fun beforeAfter() {
        val timeline = Timeframe.fromYears(1995, 2000).toDays()
        val first = timeline.first()
        val last = timeline.last()
        assertEquals(timeline.lastIndex, timeline.latestNotAfter(last))
        assertEquals(0, timeline.earliestNotBefore(first))
    }

    @Test
    fun split() {
        val tl = Timeframe.fromYears(1987, 1999).toDays()
        val list = tl.split(200)
        assertEquals(tl.first(), list.first().start)
        assertEquals(tl.last() + 1, list.last().end)
    }

    @Test
    fun timeframe() {
        val timeline = Timeframe.fromYears(1987, 1999).toDays()
        val tf = timeline.timeframe
        assertEquals(Timeframe.inclusive(timeline.first(), timeline.last()), tf)
    }


}